@@ -1,9 +1,9 @@
 //! TcpStream wrappers that supports connecting with options
 
 #[cfg(unix)]
-use std::os::unix::io::{AsRawFd, FromRawFd, IntoRawFd};
+use std::os::unix::io::{AsRawFd, FromRawFd, IntoRawFd, RawFd};
 #[cfg(windows)]
-use std::os::windows::io::{AsRawSocket, FromRawSocket, IntoRawSocket};
+use std::os::windows::io::{AsRawSocket, FromRawSocket, IntoRawSocket, RawSocket};
 use std::{
     io::{self, ErrorKind},
     net::SocketAddr,
@@ -218,6 +218,11 @@ impl TcpListener {
     pub async fn accept(&self) -> io::Result<(TokioTcpStream, SocketAddr)> {
         future::poll_fn(|cx| self.poll_accept(cx)).await
     }
+
+    /// Unwraps and take the internal `TcpListener`
+    pub fn into_inner(self) -> TokioTcpListener {
+        self.inner
+    }
 }
 
 impl Deref for TcpListener {
@@ -330,3 +335,17 @@ fn setsockopt_with_opt(f: &tokio::net::TcpStream, opts: &AcceptOpts) -> io::Resu
     f.set_nodelay(opts.tcp.nodelay)?;
     Ok(())
 }
+
+#[cfg(unix)]
+impl AsRawFd for TcpStream {
+    fn as_raw_fd(&self) -> RawFd {
+        self.0.as_raw_fd()
+    }
+}
+
+#[cfg(windows)]
+impl AsRawSocket for TcpStream {
+    fn as_raw_socket(&self) -> RawSocket {
+        self.0.as_raw_socket()
+    }
+}
